@@ -309,6 +309,9 @@ because '3.14' contains a dot, so it's not a correct TGMK literal.
 
 11. HISTORY
 
+    • 0.4.2
+        • updated: documentation
+
     • 0.4.1
         • first version published on pypi.org
 '''
@@ -321,7 +324,7 @@ from re import error as ReError
 
 #----- constants -----
 
-__version__ = '0.4.1'
+__version__ = '0.4.2'
 __all__ = ['csmatch','cimatch','cxmatch']
 
 PATTERN, LEFT, RIGHT, OR, AND, NOT = '*(),&^' # tokens: patterns and operators
